==========
eazyserver
==========


.. image:: https://img.shields.io/pypi/v/eazyserver.svg
        :target: https://pypi.python.org/pypi/eazyserver

.. image:: https://img.shields.io/travis/ashutoshdtu/eazyserver.svg
        :target: https://travis-ci.org/ashutoshdtu/eazyserver

.. image:: https://readthedocs.org/projects/eazyserver/badge/?version=latest
        :target: https://eazyserver.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/ashutoshdtu/eazyserver/shield.svg
     :target: https://pyup.io/repos/github/ashutoshdtu/eazyserver/
     :alt: Updates

.. image:: https://pyup.io/repos/github/ashutoshdtu/eazyserver/python-3-shield.svg
     :target: https://pyup.io/repos/github/ashutoshdtu/eazyserver/
     :alt: Python 3

A simple python web framework for creating RESTful and JSON-RPC services


* Free software: MIT license
* Documentation: https://eazyserver.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
